@@ -14,11 +14,13 @@
 # along with Pebble.  If not, see <http://www.gnu.org/licenses/>.
 
 
+import signal
+
 from functools import wraps
 
 
 def synchronized(lock):
-    """Synchronization decorator, locks the execution on given *lock*.
+    """Locks the execution of decorated function on given *lock*.
 
     Works with both threading and multiprocessing Lock.
 
@@ -32,3 +34,26 @@ def synchronized(lock):
         return wrapper
 
     return wrap
+
+
+def sighandler(signals):
+    """Sets the decorated function as signal handler of given *signals*.
+
+    *signals* can be either a single signal or a list/tuple
+    of multiple ones.
+
+    """
+    def wrap(function):
+        if isinstance(signals, (list, tuple)):
+            for signum in signals:
+                signal.signal(signum, function)
+        else:
+            signal.signal(signals, function)
+
+        @wraps(function)
+        def wrapper(*args, **kwargs):
+            return function(*args, **kwargs)
+
+        return wrapper
+
+    return wrap
